@@ -1108,7 +1108,8 @@ def foo():
             output_file = io.StringIO()
             docformatter._main(argv=['my_fake_program', filename],
                                standard_out=output_file,
-                               standard_error=None)
+                               standard_error=None,
+                               standard_in=None)
             self.assertEqual('''\
 @@ -1,4 +1,2 @@
  def foo():
@@ -1122,7 +1123,8 @@ def foo():
         output_file = io.StringIO()
         docformatter._main(argv=['my_fake_program', 'nonexistent_file'],
                            standard_out=output_file,
-                           standard_error=output_file)
+                           standard_error=output_file,
+                           standard_in=None)
         self.assertIn('no such file', output_file.getvalue().lower())
 
     def test_in_place(self):
@@ -1135,7 +1137,9 @@ def foo():
             output_file = io.StringIO()
             docformatter._main(
                 argv=['my_fake_program', '--in-place', filename],
-                standard_out=output_file, standard_error=None)
+                standard_out=output_file,
+                standard_error=None,
+                standard_in=None)
             with open(filename) as f:
                 self.assertEqual('''\
 def foo():
@@ -1158,7 +1162,8 @@ def foo():
                     docformatter._main(argv=['my_fake_program', '--recursive',
                                              directory],
                                        standard_out=output_file,
-                                       standard_error=None)
+                                       standard_error=None,
+                                       standard_in=None)
                     self.assertEqual(
                         '',
                         output_file.getvalue().strip())
@@ -1230,11 +1235,47 @@ def foo():
      """
 ''', '\n'.join(process.communicate()[0].decode().split('\n')[2:]))
 
+    def test_invalid_range(self):
+        process = run_docformatter(['--range', '0', '1', os.devnull])
+        self.assertIn('must be positive',
+                      process.communicate()[1].decode())
+
+        process = run_docformatter(['--range', '3', '1', os.devnull])
+        self.assertIn('should be less than',
+                      process.communicate()[1].decode())
+
     def test_no_arguments(self):
         process = run_docformatter([])
         self.assertIn('arguments',
                       process.communicate()[1].decode())
 
+    def test_standard_in(self):
+        process = run_docformatter(['-'])
+
+        result = process.communicate('''\
+"""
+Hello world"""
+'''.encode())[0].decode()
+
+        self.assertEqual(0, process.returncode)
+
+        self.assertEqual(
+            '''"""Hello world."""\n''',
+            result)
+
+    def test_standard_in_with_invalid_options(self):
+        process = run_docformatter(['foo.py', '-'])
+        self.assertIn('cannot mix',
+                      process.communicate()[1].decode())
+
+        process = run_docformatter(['--in-place', '-'])
+        self.assertIn('cannot be used',
+                      process.communicate()[1].decode())
+
+        process = run_docformatter(['--recursive', '-'])
+        self.assertIn('cannot be used',
+                      process.communicate()[1].decode())
+
 
 def generate_random_docstring(max_indentation_length=32,
                               max_word_length=20,
@@ -1303,6 +1344,7 @@ def run_docformatter(arguments):
     return subprocess.Popen(DOCFORMATTER_COMMAND + arguments,
                             stdout=subprocess.PIPE,
                             stderr=subprocess.PIPE,
+                            stdin=subprocess.PIPE,
                             env=environ)
 
 
